# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: cosmwasm/wasm/v1/genesis.proto, cosmwasm/wasm/v1/ibc.proto, cosmwasm/wasm/v1/proposal.proto, cosmwasm/wasm/v1/query.proto, cosmwasm/wasm/v1/tx.proto, cosmwasm/wasm/v1/types.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    List,
    Optional,
)

import betterproto
import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf
import grpclib
from betterproto.grpc.grpclib_server import ServiceBase

from ....cosmos.base import v1beta1 as ___cosmos_base_v1_beta1__
from ....cosmos.base.query import v1beta1 as ___cosmos_base_query_v1_beta1__


if TYPE_CHECKING:
    import grpclib.server
    from betterproto.grpc.grpclib_client import MetadataLike
    from grpclib.metadata import Deadline


class AccessType(betterproto.Enum):
    """AccessType permission types"""

    UNSPECIFIED = 0
    """AccessTypeUnspecified placeholder for empty value"""

    NOBODY = 1
    """AccessTypeNobody forbidden"""

    ONLY_ADDRESS = 2
    """AccessTypeOnlyAddress restricted to an address"""

    EVERYBODY = 3
    """AccessTypeEverybody unrestricted"""


class ContractCodeHistoryOperationType(betterproto.Enum):
    """ContractCodeHistoryOperationType actions that caused a code change"""

    UNSPECIFIED = 0
    """
    ContractCodeHistoryOperationTypeUnspecified placeholder for empty value
    """

    INIT = 1
    """ContractCodeHistoryOperationTypeInit on chain contract instantiation"""

    MIGRATE = 2
    """ContractCodeHistoryOperationTypeMigrate code migration"""

    GENESIS = 3
    """ContractCodeHistoryOperationTypeGenesis based on genesis data"""


@dataclass(eq=False, repr=False)
class AccessTypeParam(betterproto.Message):
    """AccessTypeParam"""

    value: "AccessType" = betterproto.enum_field(1)


@dataclass(eq=False, repr=False)
class AccessConfig(betterproto.Message):
    """AccessConfig access control type."""

    permission: "AccessType" = betterproto.enum_field(1)
    address: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class Params(betterproto.Message):
    """Params defines the set of wasm parameters."""

    code_upload_access: "AccessConfig" = betterproto.message_field(1)
    instantiate_default_permission: "AccessType" = betterproto.enum_field(2)


@dataclass(eq=False, repr=False)
class CodeInfo(betterproto.Message):
    """CodeInfo is data for the uploaded contract WASM code"""

    code_hash: bytes = betterproto.bytes_field(1)
    """CodeHash is the unique identifier created by wasmvm"""

    creator: str = betterproto.string_field(2)
    """Creator address who initially stored the code"""

    instantiate_config: "AccessConfig" = betterproto.message_field(5)
    """
    InstantiateConfig access control to apply on contract creation, optional
    """


@dataclass(eq=False, repr=False)
class ContractInfo(betterproto.Message):
    """ContractInfo stores a WASM contract instance"""

    code_id: int = betterproto.uint64_field(1)
    """CodeID is the reference to the stored Wasm code"""

    creator: str = betterproto.string_field(2)
    """Creator address who initially instantiated the contract"""

    admin: str = betterproto.string_field(3)
    """Admin is an optional address that can execute migrations"""

    label: str = betterproto.string_field(4)
    """Label is optional metadata to be stored with a contract instance."""

    created: "AbsoluteTxPosition" = betterproto.message_field(5)
    """
    Created Tx position when the contract was instantiated.
     This data should kept internal and not be exposed via query results. Just
     use for sorting
    """

    ibc_port_id: str = betterproto.string_field(6)
    extension: "betterproto_lib_google_protobuf.Any" = betterproto.message_field(7)
    """
    Extension is an extension point to store custom metadata within the
     persistence model.
    """


@dataclass(eq=False, repr=False)
class ContractCodeHistoryEntry(betterproto.Message):
    """ContractCodeHistoryEntry metadata to a contract."""

    operation: "ContractCodeHistoryOperationType" = betterproto.enum_field(1)
    code_id: int = betterproto.uint64_field(2)
    """CodeID is the reference to the stored WASM code"""

    updated: "AbsoluteTxPosition" = betterproto.message_field(3)
    """Updated Tx position when the operation was executed."""

    msg: bytes = betterproto.bytes_field(4)


@dataclass(eq=False, repr=False)
class AbsoluteTxPosition(betterproto.Message):
    """
    AbsoluteTxPosition is a unique transaction position that allows for global
     ordering of transactions.
    """

    block_height: int = betterproto.uint64_field(1)
    """BlockHeight is the block the contract was created at"""

    tx_index: int = betterproto.uint64_field(2)
    """
    TxIndex is a monotonic counter within the block (actual transaction index,
     or gas consumed)
    """


@dataclass(eq=False, repr=False)
class Model(betterproto.Message):
    """Model is a struct that holds a KV pair"""

    key: bytes = betterproto.bytes_field(1)
    """hex-encode key to read it better (this is often ascii)"""

    value: bytes = betterproto.bytes_field(2)
    """base64-encode raw value"""


@dataclass(eq=False, repr=False)
class MsgStoreCode(betterproto.Message):
    """MsgStoreCode submit Wasm code to the system"""

    sender: str = betterproto.string_field(1)
    """Sender is the that actor that signed the messages"""

    wasm_byte_code: bytes = betterproto.bytes_field(2)
    """WASMByteCode can be raw or gzip compressed"""

    instantiate_permission: "AccessConfig" = betterproto.message_field(5)
    """
    InstantiatePermission access control to apply on contract creation,
     optional
    """


@dataclass(eq=False, repr=False)
class MsgStoreCodeResponse(betterproto.Message):
    """MsgStoreCodeResponse returns store result data."""

    code_id: int = betterproto.uint64_field(1)
    """CodeID is the reference to the stored WASM code"""


@dataclass(eq=False, repr=False)
class MsgInstantiateContract(betterproto.Message):
    """
    MsgInstantiateContract create a new smart contract instance for the given
     code id.
    """

    sender: str = betterproto.string_field(1)
    """Sender is the that actor that signed the messages"""

    admin: str = betterproto.string_field(2)
    """Admin is an optional address that can execute migrations"""

    code_id: int = betterproto.uint64_field(3)
    """CodeID is the reference to the stored WASM code"""

    label: str = betterproto.string_field(4)
    """Label is optional metadata to be stored with a contract instance."""

    msg: bytes = betterproto.bytes_field(5)
    """
    Msg json encoded message to be passed to the contract on instantiation
    """

    funds: List["___cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(6)
    """Funds coins that are transferred to the contract on instantiation"""


@dataclass(eq=False, repr=False)
class MsgInstantiateContractResponse(betterproto.Message):
    """MsgInstantiateContractResponse return instantiation result data"""

    address: str = betterproto.string_field(1)
    """Address is the bech32 address of the new contract instance."""

    data: bytes = betterproto.bytes_field(2)
    """Data contains base64-encoded bytes to returned from the contract"""


@dataclass(eq=False, repr=False)
class MsgExecuteContract(betterproto.Message):
    """
    MsgExecuteContract submits the given message data to a smart contract
    """

    sender: str = betterproto.string_field(1)
    """Sender is the that actor that signed the messages"""

    contract: str = betterproto.string_field(2)
    """Contract is the address of the smart contract"""

    msg: bytes = betterproto.bytes_field(3)
    """Msg json encoded message to be passed to the contract"""

    funds: List["___cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(5)
    """Funds coins that are transferred to the contract on execution"""


@dataclass(eq=False, repr=False)
class MsgExecuteContractResponse(betterproto.Message):
    """MsgExecuteContractResponse returns execution result data."""

    data: bytes = betterproto.bytes_field(1)
    """Data contains base64-encoded bytes to returned from the contract"""


@dataclass(eq=False, repr=False)
class MsgMigrateContract(betterproto.Message):
    """
    MsgMigrateContract runs a code upgrade/ downgrade for a smart contract
    """

    sender: str = betterproto.string_field(1)
    """Sender is the that actor that signed the messages"""

    contract: str = betterproto.string_field(2)
    """Contract is the address of the smart contract"""

    code_id: int = betterproto.uint64_field(3)
    """CodeID references the new WASM code"""

    msg: bytes = betterproto.bytes_field(4)
    """Msg json encoded message to be passed to the contract on migration"""


@dataclass(eq=False, repr=False)
class MsgMigrateContractResponse(betterproto.Message):
    """MsgMigrateContractResponse returns contract migration result data."""

    data: bytes = betterproto.bytes_field(1)
    """
    Data contains same raw bytes returned as data from the wasm contract.
     (May be empty)
    """


@dataclass(eq=False, repr=False)
class MsgUpdateAdmin(betterproto.Message):
    """MsgUpdateAdmin sets a new admin for a smart contract"""

    sender: str = betterproto.string_field(1)
    """Sender is the that actor that signed the messages"""

    new_admin: str = betterproto.string_field(2)
    """NewAdmin address to be set"""

    contract: str = betterproto.string_field(3)
    """Contract is the address of the smart contract"""


@dataclass(eq=False, repr=False)
class MsgUpdateAdminResponse(betterproto.Message):
    """MsgUpdateAdminResponse returns empty data"""

    pass


@dataclass(eq=False, repr=False)
class MsgClearAdmin(betterproto.Message):
    """MsgClearAdmin removes any admin stored for a smart contract"""

    sender: str = betterproto.string_field(1)
    """Sender is the that actor that signed the messages"""

    contract: str = betterproto.string_field(3)
    """Contract is the address of the smart contract"""


@dataclass(eq=False, repr=False)
class MsgClearAdminResponse(betterproto.Message):
    """MsgClearAdminResponse returns empty data"""

    pass


@dataclass(eq=False, repr=False)
class QueryContractInfoRequest(betterproto.Message):
    """
    QueryContractInfoRequest is the request type for the Query/ContractInfo RPC
     method
    """

    address: str = betterproto.string_field(1)
    """address is the address of the contract to query"""


@dataclass(eq=False, repr=False)
class QueryContractInfoResponse(betterproto.Message):
    """
    QueryContractInfoResponse is the response type for the Query/ContractInfo RPC
     method
    """

    address: str = betterproto.string_field(1)
    """address is the address of the contract"""

    contract_info: "ContractInfo" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class QueryContractHistoryRequest(betterproto.Message):
    """
    QueryContractHistoryRequest is the request type for the Query/ContractHistory
     RPC method
    """

    address: str = betterproto.string_field(1)
    """address is the address of the contract to query"""

    pagination: "___cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(2)
    )
    """pagination defines an optional pagination for the request."""


@dataclass(eq=False, repr=False)
class QueryContractHistoryResponse(betterproto.Message):
    """
    QueryContractHistoryResponse is the response type for the
     Query/ContractHistory RPC method
    """

    entries: List["ContractCodeHistoryEntry"] = betterproto.message_field(1)
    pagination: "___cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )
    """pagination defines the pagination in the response."""


@dataclass(eq=False, repr=False)
class QueryContractsByCodeRequest(betterproto.Message):
    """
    QueryContractsByCodeRequest is the request type for the Query/ContractsByCode
     RPC method
    """

    code_id: int = betterproto.uint64_field(1)
    pagination: "___cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(2)
    )
    """pagination defines an optional pagination for the request."""


@dataclass(eq=False, repr=False)
class QueryContractsByCodeResponse(betterproto.Message):
    """
    QueryContractsByCodeResponse is the response type for the
     Query/ContractsByCode RPC method
    """

    contracts: List[str] = betterproto.string_field(1)
    """contracts are a set of contract addresses"""

    pagination: "___cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )
    """pagination defines the pagination in the response."""


@dataclass(eq=False, repr=False)
class QueryAllContractStateRequest(betterproto.Message):
    """
    QueryAllContractStateRequest is the request type for the
     Query/AllContractState RPC method
    """

    address: str = betterproto.string_field(1)
    """address is the address of the contract"""

    pagination: "___cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(2)
    )
    """pagination defines an optional pagination for the request."""


@dataclass(eq=False, repr=False)
class QueryAllContractStateResponse(betterproto.Message):
    """
    QueryAllContractStateResponse is the response type for the
     Query/AllContractState RPC method
    """

    models: List["Model"] = betterproto.message_field(1)
    pagination: "___cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )
    """pagination defines the pagination in the response."""


@dataclass(eq=False, repr=False)
class QueryRawContractStateRequest(betterproto.Message):
    """
    QueryRawContractStateRequest is the request type for the
     Query/RawContractState RPC method
    """

    address: str = betterproto.string_field(1)
    """address is the address of the contract"""

    query_data: bytes = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class QueryRawContractStateResponse(betterproto.Message):
    """
    QueryRawContractStateResponse is the response type for the
     Query/RawContractState RPC method
    """

    data: bytes = betterproto.bytes_field(1)
    """Data contains the raw store data"""


@dataclass(eq=False, repr=False)
class QuerySmartContractStateRequest(betterproto.Message):
    """
    QuerySmartContractStateRequest is the request type for the
     Query/SmartContractState RPC method
    """

    address: str = betterproto.string_field(1)
    """address is the address of the contract"""

    query_data: bytes = betterproto.bytes_field(2)
    """QueryData contains the query data passed to the contract"""


@dataclass(eq=False, repr=False)
class QuerySmartContractStateResponse(betterproto.Message):
    """
    QuerySmartContractStateResponse is the response type for the
     Query/SmartContractState RPC method
    """

    data: bytes = betterproto.bytes_field(1)
    """Data contains the json data returned from the smart contract"""


@dataclass(eq=False, repr=False)
class QueryCodeRequest(betterproto.Message):
    """QueryCodeRequest is the request type for the Query/Code RPC method"""

    code_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class CodeInfoResponse(betterproto.Message):
    """CodeInfoResponse contains code meta data from CodeInfo"""

    code_id: int = betterproto.uint64_field(1)
    creator: str = betterproto.string_field(2)
    data_hash: bytes = betterproto.bytes_field(3)
    instantiate_permission: "AccessConfig" = betterproto.message_field(6)


@dataclass(eq=False, repr=False)
class QueryCodeResponse(betterproto.Message):
    """QueryCodeResponse is the response type for the Query/Code RPC method"""

    code_info: "CodeInfoResponse" = betterproto.message_field(1)
    data: bytes = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class QueryCodesRequest(betterproto.Message):
    """QueryCodesRequest is the request type for the Query/Codes RPC method"""

    pagination: "___cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )
    """pagination defines an optional pagination for the request."""


@dataclass(eq=False, repr=False)
class QueryCodesResponse(betterproto.Message):
    """
    QueryCodesResponse is the response type for the Query/Codes RPC method
    """

    code_infos: List["CodeInfoResponse"] = betterproto.message_field(1)
    pagination: "___cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )
    """pagination defines the pagination in the response."""


@dataclass(eq=False, repr=False)
class QueryPinnedCodesRequest(betterproto.Message):
    """
    QueryPinnedCodesRequest is the request type for the Query/PinnedCodes
     RPC method
    """

    pagination: "___cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(2)
    )
    """pagination defines an optional pagination for the request."""


@dataclass(eq=False, repr=False)
class QueryPinnedCodesResponse(betterproto.Message):
    """
    QueryPinnedCodesResponse is the response type for the
     Query/PinnedCodes RPC method
    """

    code_ids: List[int] = betterproto.uint64_field(1)
    pagination: "___cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )
    """pagination defines the pagination in the response."""


@dataclass(eq=False, repr=False)
class GenesisState(betterproto.Message):
    """GenesisState - genesis state of x/wasm"""

    params: "Params" = betterproto.message_field(1)
    codes: List["Code"] = betterproto.message_field(2)
    contracts: List["Contract"] = betterproto.message_field(3)
    sequences: List["Sequence"] = betterproto.message_field(4)
    gen_msgs: List["GenesisStateGenMsgs"] = betterproto.message_field(5)


@dataclass(eq=False, repr=False)
class GenesisStateGenMsgs(betterproto.Message):
    """
    GenMsgs define the messages that can be executed during genesis phase in
     order. The intention is to have more human readable data that is auditable.
    """

    store_code: "MsgStoreCode" = betterproto.message_field(1, group="sum")
    instantiate_contract: "MsgInstantiateContract" = betterproto.message_field(
        2, group="sum"
    )
    execute_contract: "MsgExecuteContract" = betterproto.message_field(3, group="sum")


@dataclass(eq=False, repr=False)
class Code(betterproto.Message):
    """Code struct encompasses CodeInfo and CodeBytes"""

    code_id: int = betterproto.uint64_field(1)
    code_info: "CodeInfo" = betterproto.message_field(2)
    code_bytes: bytes = betterproto.bytes_field(3)
    pinned: bool = betterproto.bool_field(4)
    """Pinned to wasmvm cache"""


@dataclass(eq=False, repr=False)
class Contract(betterproto.Message):
    """
    Contract struct encompasses ContractAddress, ContractInfo, and ContractState
    """

    contract_address: str = betterproto.string_field(1)
    contract_info: "ContractInfo" = betterproto.message_field(2)
    contract_state: List["Model"] = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class Sequence(betterproto.Message):
    """Sequence key and value of an id generation counter"""

    id_key: bytes = betterproto.bytes_field(1)
    value: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class StoreCodeProposal(betterproto.Message):
    """
    StoreCodeProposal gov proposal content type to submit WASM code to the system
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    run_as: str = betterproto.string_field(3)
    """
    RunAs is the address that is passed to the contract's environment as sender
    """

    wasm_byte_code: bytes = betterproto.bytes_field(4)
    """WASMByteCode can be raw or gzip compressed"""

    instantiate_permission: "AccessConfig" = betterproto.message_field(7)
    """InstantiatePermission to apply on contract creation, optional"""


@dataclass(eq=False, repr=False)
class InstantiateContractProposal(betterproto.Message):
    """
    InstantiateContractProposal gov proposal content type to instantiate a
     contract.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    run_as: str = betterproto.string_field(3)
    """
    RunAs is the address that is passed to the contract's environment as sender
    """

    admin: str = betterproto.string_field(4)
    """Admin is an optional address that can execute migrations"""

    code_id: int = betterproto.uint64_field(5)
    """CodeID is the reference to the stored WASM code"""

    label: str = betterproto.string_field(6)
    """Label is optional metadata to be stored with a constract instance."""

    msg: bytes = betterproto.bytes_field(7)
    """
    Msg json encoded message to be passed to the contract on instantiation
    """

    funds: List["___cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(8)
    """Funds coins that are transferred to the contract on instantiation"""


@dataclass(eq=False, repr=False)
class MigrateContractProposal(betterproto.Message):
    """
    MigrateContractProposal gov proposal content type to migrate a contract.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    contract: str = betterproto.string_field(4)
    """Contract is the address of the smart contract"""

    code_id: int = betterproto.uint64_field(5)
    """CodeID references the new WASM code"""

    msg: bytes = betterproto.bytes_field(6)
    """Msg json encoded message to be passed to the contract on migration"""


@dataclass(eq=False, repr=False)
class SudoContractProposal(betterproto.Message):
    """
    SudoContractProposal gov proposal content type to call sudo on a contract.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    contract: str = betterproto.string_field(3)
    """Contract is the address of the smart contract"""

    msg: bytes = betterproto.bytes_field(4)
    """Msg json encoded message to be passed to the contract as sudo"""


@dataclass(eq=False, repr=False)
class ExecuteContractProposal(betterproto.Message):
    """
    ExecuteContractProposal gov proposal content type to call execute on a
     contract.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    run_as: str = betterproto.string_field(3)
    """
    RunAs is the address that is passed to the contract's environment as sender
    """

    contract: str = betterproto.string_field(4)
    """Contract is the address of the smart contract"""

    msg: bytes = betterproto.bytes_field(5)
    """Msg json encoded message to be passed to the contract as execute"""

    funds: List["___cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(6)
    """Funds coins that are transferred to the contract on instantiation"""


@dataclass(eq=False, repr=False)
class UpdateAdminProposal(betterproto.Message):
    """
    UpdateAdminProposal gov proposal content type to set an admin for a contract.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    new_admin: str = betterproto.string_field(3)
    """NewAdmin address to be set"""

    contract: str = betterproto.string_field(4)
    """Contract is the address of the smart contract"""


@dataclass(eq=False, repr=False)
class ClearAdminProposal(betterproto.Message):
    """
    ClearAdminProposal gov proposal content type to clear the admin of a
     contract.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    contract: str = betterproto.string_field(3)
    """Contract is the address of the smart contract"""


@dataclass(eq=False, repr=False)
class PinCodesProposal(betterproto.Message):
    """
    PinCodesProposal gov proposal content type to pin a set of code ids in the
     wasmvm cache.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    code_ids: List[int] = betterproto.uint64_field(3)
    """CodeIDs references the new WASM codes"""


@dataclass(eq=False, repr=False)
class UnpinCodesProposal(betterproto.Message):
    """
    UnpinCodesProposal gov proposal content type to unpin a set of code ids in
     the wasmvm cache.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    code_ids: List[int] = betterproto.uint64_field(3)
    """CodeIDs references the WASM codes"""


@dataclass(eq=False, repr=False)
class AccessConfigUpdate(betterproto.Message):
    """
    AccessConfigUpdate contains the code id and the access config to be
     applied.
    """

    code_id: int = betterproto.uint64_field(1)
    """CodeID is the reference to the stored WASM code to be updated"""

    instantiate_permission: "AccessConfig" = betterproto.message_field(2)
    """InstantiatePermission to apply to the set of code ids"""


@dataclass(eq=False, repr=False)
class UpdateInstantiateConfigProposal(betterproto.Message):
    """
    UpdateInstantiateConfigProposal gov proposal content type to update
     instantiate config to a  set of code ids.
    """

    title: str = betterproto.string_field(1)
    """Title is a short summary"""

    description: str = betterproto.string_field(2)
    """Description is a human readable text"""

    access_config_updates: List["AccessConfigUpdate"] = betterproto.message_field(3)
    """
    AccessConfigUpdate contains the list of code ids and the access config
     to be applied.
    """


@dataclass(eq=False, repr=False)
class MsgIbcSend(betterproto.Message):
    """MsgIBCSend"""

    channel: str = betterproto.string_field(2)
    """the channel by which the packet will be sent"""

    timeout_height: int = betterproto.uint64_field(4)
    """
    Timeout height relative to the current block height.
     The timeout is disabled when set to 0.
    """

    timeout_timestamp: int = betterproto.uint64_field(5)
    """
    Timeout timestamp (in nanoseconds) relative to the current block timestamp.
     The timeout is disabled when set to 0.
    """

    data: bytes = betterproto.bytes_field(6)
    """
    Data is the payload to transfer. We must not make assumption what format or
     content is in here.
    """


@dataclass(eq=False, repr=False)
class MsgIbcCloseChannel(betterproto.Message):
    """MsgIBCCloseChannel port and channel need to be owned by the contract"""

    channel: str = betterproto.string_field(2)


class MsgStub(betterproto.ServiceStub):
    async def store_code(
        self,
        msg_store_code: "MsgStoreCode",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgStoreCodeResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Msg/StoreCode",
            msg_store_code,
            MsgStoreCodeResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def instantiate_contract(
        self,
        msg_instantiate_contract: "MsgInstantiateContract",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgInstantiateContractResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Msg/InstantiateContract",
            msg_instantiate_contract,
            MsgInstantiateContractResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def execute_contract(
        self,
        msg_execute_contract: "MsgExecuteContract",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgExecuteContractResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Msg/ExecuteContract",
            msg_execute_contract,
            MsgExecuteContractResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def migrate_contract(
        self,
        msg_migrate_contract: "MsgMigrateContract",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgMigrateContractResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Msg/MigrateContract",
            msg_migrate_contract,
            MsgMigrateContractResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def update_admin(
        self,
        msg_update_admin: "MsgUpdateAdmin",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgUpdateAdminResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Msg/UpdateAdmin",
            msg_update_admin,
            MsgUpdateAdminResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def clear_admin(
        self,
        msg_clear_admin: "MsgClearAdmin",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgClearAdminResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Msg/ClearAdmin",
            msg_clear_admin,
            MsgClearAdminResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class QueryStub(betterproto.ServiceStub):
    async def contract_info(
        self,
        query_contract_info_request: "QueryContractInfoRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryContractInfoResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/ContractInfo",
            query_contract_info_request,
            QueryContractInfoResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def contract_history(
        self,
        query_contract_history_request: "QueryContractHistoryRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryContractHistoryResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/ContractHistory",
            query_contract_history_request,
            QueryContractHistoryResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def contracts_by_code(
        self,
        query_contracts_by_code_request: "QueryContractsByCodeRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryContractsByCodeResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/ContractsByCode",
            query_contracts_by_code_request,
            QueryContractsByCodeResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def all_contract_state(
        self,
        query_all_contract_state_request: "QueryAllContractStateRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryAllContractStateResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/AllContractState",
            query_all_contract_state_request,
            QueryAllContractStateResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def raw_contract_state(
        self,
        query_raw_contract_state_request: "QueryRawContractStateRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryRawContractStateResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/RawContractState",
            query_raw_contract_state_request,
            QueryRawContractStateResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def smart_contract_state(
        self,
        query_smart_contract_state_request: "QuerySmartContractStateRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QuerySmartContractStateResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/SmartContractState",
            query_smart_contract_state_request,
            QuerySmartContractStateResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def code(
        self,
        query_code_request: "QueryCodeRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryCodeResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/Code",
            query_code_request,
            QueryCodeResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def codes(
        self,
        query_codes_request: "QueryCodesRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryCodesResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/Codes",
            query_codes_request,
            QueryCodesResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def pinned_codes(
        self,
        query_pinned_codes_request: "QueryPinnedCodesRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryPinnedCodesResponse":
        return await self._unary_unary(
            "/cosmwasm.wasm.v1.Query/PinnedCodes",
            query_pinned_codes_request,
            QueryPinnedCodesResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class MsgBase(ServiceBase):
    async def store_code(
        self, msg_store_code: "MsgStoreCode"
    ) -> "MsgStoreCodeResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def instantiate_contract(
        self, msg_instantiate_contract: "MsgInstantiateContract"
    ) -> "MsgInstantiateContractResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def execute_contract(
        self, msg_execute_contract: "MsgExecuteContract"
    ) -> "MsgExecuteContractResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def migrate_contract(
        self, msg_migrate_contract: "MsgMigrateContract"
    ) -> "MsgMigrateContractResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def update_admin(
        self, msg_update_admin: "MsgUpdateAdmin"
    ) -> "MsgUpdateAdminResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def clear_admin(
        self, msg_clear_admin: "MsgClearAdmin"
    ) -> "MsgClearAdminResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_store_code(
        self, stream: "grpclib.server.Stream[MsgStoreCode, MsgStoreCodeResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.store_code(request)
        await stream.send_message(response)

    async def __rpc_instantiate_contract(
        self,
        stream: "grpclib.server.Stream[MsgInstantiateContract, MsgInstantiateContractResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.instantiate_contract(request)
        await stream.send_message(response)

    async def __rpc_execute_contract(
        self,
        stream: "grpclib.server.Stream[MsgExecuteContract, MsgExecuteContractResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.execute_contract(request)
        await stream.send_message(response)

    async def __rpc_migrate_contract(
        self,
        stream: "grpclib.server.Stream[MsgMigrateContract, MsgMigrateContractResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.migrate_contract(request)
        await stream.send_message(response)

    async def __rpc_update_admin(
        self, stream: "grpclib.server.Stream[MsgUpdateAdmin, MsgUpdateAdminResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.update_admin(request)
        await stream.send_message(response)

    async def __rpc_clear_admin(
        self, stream: "grpclib.server.Stream[MsgClearAdmin, MsgClearAdminResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.clear_admin(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/cosmwasm.wasm.v1.Msg/StoreCode": grpclib.const.Handler(
                self.__rpc_store_code,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgStoreCode,
                MsgStoreCodeResponse,
            ),
            "/cosmwasm.wasm.v1.Msg/InstantiateContract": grpclib.const.Handler(
                self.__rpc_instantiate_contract,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgInstantiateContract,
                MsgInstantiateContractResponse,
            ),
            "/cosmwasm.wasm.v1.Msg/ExecuteContract": grpclib.const.Handler(
                self.__rpc_execute_contract,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgExecuteContract,
                MsgExecuteContractResponse,
            ),
            "/cosmwasm.wasm.v1.Msg/MigrateContract": grpclib.const.Handler(
                self.__rpc_migrate_contract,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgMigrateContract,
                MsgMigrateContractResponse,
            ),
            "/cosmwasm.wasm.v1.Msg/UpdateAdmin": grpclib.const.Handler(
                self.__rpc_update_admin,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgUpdateAdmin,
                MsgUpdateAdminResponse,
            ),
            "/cosmwasm.wasm.v1.Msg/ClearAdmin": grpclib.const.Handler(
                self.__rpc_clear_admin,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgClearAdmin,
                MsgClearAdminResponse,
            ),
        }


class QueryBase(ServiceBase):
    async def contract_info(
        self, query_contract_info_request: "QueryContractInfoRequest"
    ) -> "QueryContractInfoResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def contract_history(
        self, query_contract_history_request: "QueryContractHistoryRequest"
    ) -> "QueryContractHistoryResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def contracts_by_code(
        self, query_contracts_by_code_request: "QueryContractsByCodeRequest"
    ) -> "QueryContractsByCodeResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def all_contract_state(
        self, query_all_contract_state_request: "QueryAllContractStateRequest"
    ) -> "QueryAllContractStateResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def raw_contract_state(
        self, query_raw_contract_state_request: "QueryRawContractStateRequest"
    ) -> "QueryRawContractStateResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def smart_contract_state(
        self, query_smart_contract_state_request: "QuerySmartContractStateRequest"
    ) -> "QuerySmartContractStateResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def code(self, query_code_request: "QueryCodeRequest") -> "QueryCodeResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def codes(
        self, query_codes_request: "QueryCodesRequest"
    ) -> "QueryCodesResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def pinned_codes(
        self, query_pinned_codes_request: "QueryPinnedCodesRequest"
    ) -> "QueryPinnedCodesResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_contract_info(
        self,
        stream: "grpclib.server.Stream[QueryContractInfoRequest, QueryContractInfoResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.contract_info(request)
        await stream.send_message(response)

    async def __rpc_contract_history(
        self,
        stream: "grpclib.server.Stream[QueryContractHistoryRequest, QueryContractHistoryResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.contract_history(request)
        await stream.send_message(response)

    async def __rpc_contracts_by_code(
        self,
        stream: "grpclib.server.Stream[QueryContractsByCodeRequest, QueryContractsByCodeResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.contracts_by_code(request)
        await stream.send_message(response)

    async def __rpc_all_contract_state(
        self,
        stream: "grpclib.server.Stream[QueryAllContractStateRequest, QueryAllContractStateResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.all_contract_state(request)
        await stream.send_message(response)

    async def __rpc_raw_contract_state(
        self,
        stream: "grpclib.server.Stream[QueryRawContractStateRequest, QueryRawContractStateResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.raw_contract_state(request)
        await stream.send_message(response)

    async def __rpc_smart_contract_state(
        self,
        stream: "grpclib.server.Stream[QuerySmartContractStateRequest, QuerySmartContractStateResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.smart_contract_state(request)
        await stream.send_message(response)

    async def __rpc_code(
        self, stream: "grpclib.server.Stream[QueryCodeRequest, QueryCodeResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.code(request)
        await stream.send_message(response)

    async def __rpc_codes(
        self, stream: "grpclib.server.Stream[QueryCodesRequest, QueryCodesResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.codes(request)
        await stream.send_message(response)

    async def __rpc_pinned_codes(
        self,
        stream: "grpclib.server.Stream[QueryPinnedCodesRequest, QueryPinnedCodesResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.pinned_codes(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/cosmwasm.wasm.v1.Query/ContractInfo": grpclib.const.Handler(
                self.__rpc_contract_info,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryContractInfoRequest,
                QueryContractInfoResponse,
            ),
            "/cosmwasm.wasm.v1.Query/ContractHistory": grpclib.const.Handler(
                self.__rpc_contract_history,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryContractHistoryRequest,
                QueryContractHistoryResponse,
            ),
            "/cosmwasm.wasm.v1.Query/ContractsByCode": grpclib.const.Handler(
                self.__rpc_contracts_by_code,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryContractsByCodeRequest,
                QueryContractsByCodeResponse,
            ),
            "/cosmwasm.wasm.v1.Query/AllContractState": grpclib.const.Handler(
                self.__rpc_all_contract_state,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryAllContractStateRequest,
                QueryAllContractStateResponse,
            ),
            "/cosmwasm.wasm.v1.Query/RawContractState": grpclib.const.Handler(
                self.__rpc_raw_contract_state,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryRawContractStateRequest,
                QueryRawContractStateResponse,
            ),
            "/cosmwasm.wasm.v1.Query/SmartContractState": grpclib.const.Handler(
                self.__rpc_smart_contract_state,
                grpclib.const.Cardinality.UNARY_UNARY,
                QuerySmartContractStateRequest,
                QuerySmartContractStateResponse,
            ),
            "/cosmwasm.wasm.v1.Query/Code": grpclib.const.Handler(
                self.__rpc_code,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryCodeRequest,
                QueryCodeResponse,
            ),
            "/cosmwasm.wasm.v1.Query/Codes": grpclib.const.Handler(
                self.__rpc_codes,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryCodesRequest,
                QueryCodesResponse,
            ),
            "/cosmwasm.wasm.v1.Query/PinnedCodes": grpclib.const.Handler(
                self.__rpc_pinned_codes,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryPinnedCodesRequest,
                QueryPinnedCodesResponse,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ibc/core/types/v1/genesis.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass

import betterproto

from ...channel import v1 as __channel_v1__
from ...client import v1 as __client_v1__
from ...connection import v1 as __connection_v1__


@dataclass(eq=False, repr=False)
class GenesisState(betterproto.Message):
    """GenesisState defines the ibc module's genesis state."""

    client_genesis: "__client_v1__.GenesisState" = betterproto.message_field(1)
    """ICS002 - Clients genesis state"""

    connection_genesis: "__connection_v1__.GenesisState" = betterproto.message_field(2)
    """ICS003 - Connections genesis state"""

    channel_genesis: "__channel_v1__.GenesisState" = betterproto.message_field(3)
    """ICS004 - Channel genesis state"""



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google/protobuf/compiler/plugin.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto
import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


@dataclass(eq=False, repr=False)
class Version(betterproto.Message):
    """The version number of protocol compiler."""

    major: int = betterproto.int32_field(1)
    minor: int = betterproto.int32_field(2)
    patch: int = betterproto.int32_field(3)
    suffix: str = betterproto.string_field(4)
    """
    A suffix for alpha, beta or rc release, e.g., "alpha-1", "rc2". It should
    be empty for mainline stable releases.
    """


@dataclass(eq=False, repr=False)
class CodeGeneratorRequest(betterproto.Message):
    """An encoded CodeGeneratorRequest is written to the plugin's stdin."""

    file_to_generate: List[str] = betterproto.string_field(1)
    """
    The .proto files that were explicitly listed on the command-line.  The code
    generator should generate code only for these files.  Each file's
    descriptor will be included in proto_file, below.
    """

    parameter: str = betterproto.string_field(2)
    """The generator parameter passed on the command-line."""

    proto_file: List[
        "betterproto_lib_google_protobuf.FileDescriptorProto"
    ] = betterproto.message_field(15)
    """
    FileDescriptorProtos for all files in files_to_generate and everything they
    import.  The files will appear in topological order, so each file appears
    before any file that imports it. protoc guarantees that all proto_files
    will be written after the fields above, even though this is not technically
    guaranteed by the protobuf wire format.  This theoretically could allow a
    plugin to stream in the FileDescriptorProtos and handle them one by one
    rather than read the entire set into memory at once.  However, as of this
    writing, this is not similarly optimized on protoc's end -- it will store
    all fields in memory at once before sending them to the plugin.
    """

    compiler_version: "Version" = betterproto.message_field(3)
    """The version number of protocol compiler."""


@dataclass(eq=False, repr=False)
class CodeGeneratorResponse(betterproto.Message):
    """The plugin writes an encoded CodeGeneratorResponse to stdout."""

    error: str = betterproto.string_field(1)
    """
    Error message.  If non-empty, code generation failed.  The plugin process
    should exit with status code zero even if it reports an error in this way.
    This should be used to indicate errors in .proto files which prevent the
    code generator from generating correct code.  Errors which indicate a
    problem in protoc itself -- such as the input CodeGeneratorRequest being
    unparseable -- should be reported by writing a message to stderr and
    exiting with a non-zero status code.
    """

    file: List["CodeGeneratorResponseFile"] = betterproto.message_field(15)


@dataclass(eq=False, repr=False)
class CodeGeneratorResponseFile(betterproto.Message):
    """Represents a single generated file."""

    name: str = betterproto.string_field(1)
    """
    The file name, relative to the output directory.  The name must not contain
    "." or ".." components and must be relative, not be absolute (so, the file
    cannot lie outside the output directory).  "/" must be used as the path
    separator, not "\". If the name is omitted, the content will be appended to
    the previous file.  This allows the generator to break large files into
    small chunks, and allows the generated text to be streamed back to protoc
    so that large files need not reside completely in memory at one time.  Note
    that as of this writing protoc does not optimize for this -- it will read
    the entire CodeGeneratorResponse before writing files to disk.
    """

    insertion_point: str = betterproto.string_field(2)
    """
    If non-empty, indicates that the named file should already exist, and the
    content here is to be inserted into that file at a defined insertion point.
    This feature allows a code generator to extend the output produced by
    another code generator.  The original generator may provide insertion
    points by placing special annotations in the file that look like:
    @@protoc_insertion_point(NAME) The annotation can have arbitrary text
    before and after it on the line, which allows it to be placed in a comment.
    NAME should be replaced with an identifier naming the point -- this is what
    other generators will use as the insertion_point.  Code inserted at this
    point will be placed immediately above the line containing the insertion
    point (thus multiple insertions to the same point will come out in the
    order they were added). The double-@ is intended to make it unlikely that
    the generated code could contain things that look like insertion points by
    accident. For example, the C++ code generator places the following line in
    the .pb.h files that it generates:   //
    @@protoc_insertion_point(namespace_scope) This line appears within the
    scope of the file's package namespace, but outside of any particular class.
    Another plugin can then specify the insertion_point "namespace_scope" to
    generate additional classes or other declarations that should be placed in
    this scope. Note that if the line containing the insertion point begins
    with whitespace, the same whitespace will be added to every line of the
    inserted text.  This is useful for languages like Python, where indentation
    matters.  In these languages, the insertion point comment should be
    indented the same amount as any inserted code will need to be in order to
    work correctly in that context. The code generator that generates the
    initial file and the one which inserts into it must both run as part of a
    single invocation of protoc. Code generators are executed in the order in
    which they appear on the command line. If |insertion_point| is present,
    |name| must also be present.
    """

    content: str = betterproto.string_field(15)
    """The file contents."""



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ethermint/crypto/v1/ethsecp256k1/keys.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class PubKey(betterproto.Message):
    """
    PubKey defines a type alias for an ecdsa.PublicKey that implements
     Tendermint's PubKey interface. It represents the 33-byte compressed public
     key format.
    """

    key: bytes = betterproto.bytes_field(1)


@dataclass(eq=False, repr=False)
class PrivKey(betterproto.Message):
    """
    PrivKey defines a type alias for an ecdsa.PrivateKey that implements
     Tendermint's PrivateKey interface.
    """

    key: bytes = betterproto.bytes_field(1)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ibc/applications/fee/v1/ack.proto, ibc/applications/fee/v1/fee.proto, ibc/applications/fee/v1/genesis.proto, ibc/applications/fee/v1/metadata.proto, ibc/applications/fee/v1/query.proto, ibc/applications/fee/v1/tx.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    List,
    Optional,
)

import betterproto
import grpclib
from betterproto.grpc.grpclib_server import ServiceBase

from .....cosmos.base import v1beta1 as ____cosmos_base_v1_beta1__
from .....cosmos.base.query import v1beta1 as ____cosmos_base_query_v1_beta1__
from ....core.channel import v1 as ___core_channel_v1__


if TYPE_CHECKING:
    import grpclib.server
    from betterproto.grpc.grpclib_client import MetadataLike
    from grpclib.metadata import Deadline


@dataclass(eq=False, repr=False)
class Fee(betterproto.Message):
    """Fee defines the ICS29 receive, acknowledgement and timeout fees"""

    recv_fee: List["____cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(1)
    """the packet receive fee"""

    ack_fee: List["____cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(2)
    """the packet acknowledgement fee"""

    timeout_fee: List["____cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(3)
    """the packet timeout fee"""


@dataclass(eq=False, repr=False)
class PacketFee(betterproto.Message):
    """
    PacketFee contains ICS29 relayer fees, refund address and optional list of permitted relayers
    """

    fee: "Fee" = betterproto.message_field(1)
    """
    fee encapsulates the recv, ack and timeout fees associated with an IBC packet
    """

    refund_address: str = betterproto.string_field(2)
    """the refund address for unspent fees"""

    relayers: List[str] = betterproto.string_field(3)
    """optional list of relayers permitted to receive fees"""


@dataclass(eq=False, repr=False)
class PacketFees(betterproto.Message):
    """PacketFees contains a list of type PacketFee"""

    packet_fees: List["PacketFee"] = betterproto.message_field(1)
    """list of packet fees"""


@dataclass(eq=False, repr=False)
class IdentifiedPacketFees(betterproto.Message):
    """
    IdentifiedPacketFees contains a list of type PacketFee and associated PacketId
    """

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(1)
    """
    unique packet identifier comprised of the channel ID, port ID and sequence
    """

    packet_fees: List["PacketFee"] = betterproto.message_field(2)
    """list of packet fees"""


@dataclass(eq=False, repr=False)
class MsgRegisterCounterpartyAddress(betterproto.Message):
    """
    MsgRegisterCounterpartyAddress defines the request type for the RegisterCounterpartyAddress rpc
    """

    address: str = betterproto.string_field(1)
    """the relayer address"""

    counterparty_address: str = betterproto.string_field(2)
    """the counterparty relayer address"""

    channel_id: str = betterproto.string_field(3)
    """unique channel identifier"""


@dataclass(eq=False, repr=False)
class MsgRegisterCounterpartyAddressResponse(betterproto.Message):
    """
    MsgRegisterCounterpartyAddressResponse defines the response type for the RegisterCounterpartyAddress rpc
    """

    pass


@dataclass(eq=False, repr=False)
class MsgPayPacketFee(betterproto.Message):
    """
    MsgPayPacketFee defines the request type for the PayPacketFee rpc
     This Msg can be used to pay for a packet at the next sequence send & should be combined with the Msg that will be
     paid for
    """

    fee: "Fee" = betterproto.message_field(1)
    """
    fee encapsulates the recv, ack and timeout fees associated with an IBC packet
    """

    source_port_id: str = betterproto.string_field(2)
    """the source port unique identifier"""

    source_channel_id: str = betterproto.string_field(3)
    """the source channel unique identifer"""

    signer: str = betterproto.string_field(4)
    """account address to refund fee if necessary"""

    relayers: List[str] = betterproto.string_field(5)
    """optional list of relayers permitted to the receive packet fees"""


@dataclass(eq=False, repr=False)
class MsgPayPacketFeeResponse(betterproto.Message):
    """
    MsgPayPacketFeeResponse defines the response type for the PayPacketFee rpc
    """

    pass


@dataclass(eq=False, repr=False)
class MsgPayPacketFeeAsync(betterproto.Message):
    """
    MsgPayPacketFeeAsync defines the request type for the PayPacketFeeAsync rpc
     This Msg can be used to pay for a packet at a specified sequence (instead of the next sequence send)
    """

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(1)
    """
    unique packet identifier comprised of the channel ID, port ID and sequence
    """

    packet_fee: "PacketFee" = betterproto.message_field(2)
    """the packet fee associated with a particular IBC packet"""


@dataclass(eq=False, repr=False)
class MsgPayPacketFeeAsyncResponse(betterproto.Message):
    """
    MsgPayPacketFeeAsyncResponse defines the response type for the PayPacketFeeAsync rpc
    """

    pass


@dataclass(eq=False, repr=False)
class IncentivizedAcknowledgement(betterproto.Message):
    """
    IncentivizedAcknowledgement is the acknowledgement format to be used by applications wrapped in the fee middleware
    """

    result: bytes = betterproto.bytes_field(1)
    """the underlying app acknowledgement result bytes"""

    forward_relayer_address: str = betterproto.string_field(2)
    """the relayer address which submits the recv packet message"""

    underlying_app_success: bool = betterproto.bool_field(3)
    """success flag of the base application callback"""


@dataclass(eq=False, repr=False)
class GenesisState(betterproto.Message):
    """GenesisState defines the ICS29 fee middleware genesis state"""

    identified_fees: List["IdentifiedPacketFees"] = betterproto.message_field(1)
    """list of identified packet fees"""

    fee_enabled_channels: List["FeeEnabledChannel"] = betterproto.message_field(2)
    """list of fee enabled channels"""

    registered_relayers: List["RegisteredRelayerAddress"] = betterproto.message_field(3)
    """list of registered relayer addresses"""

    forward_relayers: List["ForwardRelayerAddress"] = betterproto.message_field(4)
    """list of forward relayer addresses"""


@dataclass(eq=False, repr=False)
class FeeEnabledChannel(betterproto.Message):
    """
    FeeEnabledChannel contains the PortID & ChannelID for a fee enabled channel
    """

    port_id: str = betterproto.string_field(1)
    """unique port identifier"""

    channel_id: str = betterproto.string_field(2)
    """unique channel identifier"""


@dataclass(eq=False, repr=False)
class RegisteredRelayerAddress(betterproto.Message):
    """
    RegisteredRelayerAddress contains the address and counterparty address for a specific relayer (for distributing fees)
    """

    address: str = betterproto.string_field(1)
    """the relayer address"""

    counterparty_address: str = betterproto.string_field(2)
    """the counterparty relayer address"""

    channel_id: str = betterproto.string_field(3)
    """unique channel identifier"""


@dataclass(eq=False, repr=False)
class ForwardRelayerAddress(betterproto.Message):
    """
    ForwardRelayerAddress contains the forward relayer address and PacketId used for async acknowledgements
    """

    address: str = betterproto.string_field(1)
    """the forward relayer address"""

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(2)
    """
    unique packet identifer comprised of the channel ID, port ID and sequence
    """


@dataclass(eq=False, repr=False)
class QueryIncentivizedPacketsRequest(betterproto.Message):
    """
    QueryIncentivizedPacketsRequest defines the request type for the IncentivizedPackets rpc
    """

    pagination: "____cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )
    """pagination defines an optional pagination for the request."""

    query_height: int = betterproto.uint64_field(2)
    """block height at which to query"""


@dataclass(eq=False, repr=False)
class QueryIncentivizedPacketsResponse(betterproto.Message):
    """
    QueryIncentivizedPacketsResponse defines the response type for the IncentivizedPackets rpc
    """

    incentivized_packets: List["IdentifiedPacketFees"] = betterproto.message_field(1)
    """list of identified fees for incentivized packets"""


@dataclass(eq=False, repr=False)
class QueryIncentivizedPacketRequest(betterproto.Message):
    """
    QueryIncentivizedPacketRequest defines the request type for the IncentivizedPacket rpc
    """

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(1)
    """
    unique packet identifier comprised of channel ID, port ID and sequence
    """

    query_height: int = betterproto.uint64_field(2)
    """block height at which to query"""


@dataclass(eq=False, repr=False)
class QueryIncentivizedPacketResponse(betterproto.Message):
    """
    QueryIncentivizedPacketsResponse defines the response type for the IncentivizedPacket rpc
    """

    incentivized_packet: "IdentifiedPacketFees" = betterproto.message_field(1)
    """the identified fees for the incentivized packet"""


@dataclass(eq=False, repr=False)
class QueryIncentivizedPacketsForChannelRequest(betterproto.Message):
    """
    QueryIncentivizedPacketsForChannelRequest defines the request type for querying for all incentivized packets
     for a specific channel
    """

    pagination: "____cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )
    """pagination defines an optional pagination for the request."""

    port_id: str = betterproto.string_field(2)
    channel_id: str = betterproto.string_field(3)
    query_height: int = betterproto.uint64_field(4)
    """Height to query at"""


@dataclass(eq=False, repr=False)
class QueryIncentivizedPacketsForChannelResponse(betterproto.Message):
    """
    QueryIncentivizedPacketsResponse defines the response type for the incentivized packets RPC
    """

    incentivized_packets: List["IdentifiedPacketFees"] = betterproto.message_field(1)
    """Map of all incentivized_packets"""


@dataclass(eq=False, repr=False)
class QueryTotalRecvFeesRequest(betterproto.Message):
    """
    QueryTotalRecvFeesRequest defines the request type for the TotalRecvFees rpc
    """

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(1)
    """the packet identifier for the associated fees"""


@dataclass(eq=False, repr=False)
class QueryTotalRecvFeesResponse(betterproto.Message):
    """
    QueryTotalRecvFeesResponse defines the response type for the TotalRecvFees rpc
    """

    recv_fees: List["____cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(1)
    """the total packet receive fees"""


@dataclass(eq=False, repr=False)
class QueryTotalAckFeesRequest(betterproto.Message):
    """
    QueryTotalAckFeesRequest defines the request type for the TotalAckFees rpc
    """

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(1)
    """the packet identifier for the associated fees"""


@dataclass(eq=False, repr=False)
class QueryTotalAckFeesResponse(betterproto.Message):
    """
    QueryTotalAckFeesResponse defines the response type for the TotalAckFees rpc
    """

    ack_fees: List["____cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(1)
    """the total packet acknowledgement fees"""


@dataclass(eq=False, repr=False)
class QueryTotalTimeoutFeesRequest(betterproto.Message):
    """
    QueryTotalTimeoutFeesRequest defines the request type for the TotalTimeoutFees rpc
    """

    packet_id: "___core_channel_v1__.PacketId" = betterproto.message_field(1)
    """the packet identifier for the associated fees"""


@dataclass(eq=False, repr=False)
class QueryTotalTimeoutFeesResponse(betterproto.Message):
    """
    QueryTotalTimeoutFeesResponse defines the response type for the TotalTimeoutFees rpc
    """

    timeout_fees: List["____cosmos_base_v1_beta1__.Coin"] = betterproto.message_field(1)
    """the total packet timeout fees"""


@dataclass(eq=False, repr=False)
class QueryCounterpartyAddressRequest(betterproto.Message):
    """
    QueryCounterpartyAddressRequest defines the request type for the CounterpartyAddress rpc
    """

    channel_id: str = betterproto.string_field(1)
    """unique channel identifier"""

    relayer_address: str = betterproto.string_field(2)
    """the relayer address to which the counterparty is registered"""


@dataclass(eq=False, repr=False)
class QueryCounterpartyAddressResponse(betterproto.Message):
    """
    QueryCounterpartyAddressResponse defines the response type for the CounterpartyAddress rpc
    """

    counterparty_address: str = betterproto.string_field(1)
    """the counterparty address used to compensate forward relaying"""


@dataclass(eq=False, repr=False)
class QueryFeeEnabledChannelsRequest(betterproto.Message):
    """
    QueryFeeEnabledChannelsRequest defines the request type for the FeeEnabledChannels rpc
    """

    pagination: "____cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )
    """pagination defines an optional pagination for the request."""

    query_height: int = betterproto.uint64_field(2)
    """block height at which to query"""


@dataclass(eq=False, repr=False)
class QueryFeeEnabledChannelsResponse(betterproto.Message):
    """
    QueryFeeEnabledChannelsResponse defines the response type for the FeeEnabledChannels rpc
    """

    fee_enabled_channels: List["FeeEnabledChannel"] = betterproto.message_field(1)
    """list of fee enabled channels"""


@dataclass(eq=False, repr=False)
class QueryFeeEnabledChannelRequest(betterproto.Message):
    """
    QueryFeeEnabledChannelRequest defines the request type for the FeeEnabledChannel rpc
    """

    port_id: str = betterproto.string_field(1)
    """unique port identifier"""

    channel_id: str = betterproto.string_field(2)
    """unique channel identifier"""


@dataclass(eq=False, repr=False)
class QueryFeeEnabledChannelResponse(betterproto.Message):
    """
    QueryFeeEnabledChannelResponse defines the response type for the FeeEnabledChannel rpc
    """

    fee_enabled: bool = betterproto.bool_field(1)
    """boolean flag representing the fee enabled channel status"""


@dataclass(eq=False, repr=False)
class Metadata(betterproto.Message):
    """
    Metadata defines the ICS29 channel specific metadata encoded into the channel version bytestring
     See ICS004: https://github.com/cosmos/ibc/tree/master/spec/core/ics-004-channel-and-packet-semantics#Versioning
    """

    fee_version: str = betterproto.string_field(1)
    """fee_version defines the ICS29 fee version"""

    app_version: str = betterproto.string_field(2)
    """
    app_version defines the underlying application version, which may or may not be a JSON encoded bytestring
    """


class MsgStub(betterproto.ServiceStub):
    async def register_counterparty_address(
        self,
        msg_register_counterparty_address: "MsgRegisterCounterpartyAddress",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgRegisterCounterpartyAddressResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Msg/RegisterCounterpartyAddress",
            msg_register_counterparty_address,
            MsgRegisterCounterpartyAddressResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def pay_packet_fee(
        self,
        msg_pay_packet_fee: "MsgPayPacketFee",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgPayPacketFeeResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Msg/PayPacketFee",
            msg_pay_packet_fee,
            MsgPayPacketFeeResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def pay_packet_fee_async(
        self,
        msg_pay_packet_fee_async: "MsgPayPacketFeeAsync",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgPayPacketFeeAsyncResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Msg/PayPacketFeeAsync",
            msg_pay_packet_fee_async,
            MsgPayPacketFeeAsyncResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class QueryStub(betterproto.ServiceStub):
    async def incentivized_packets(
        self,
        query_incentivized_packets_request: "QueryIncentivizedPacketsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryIncentivizedPacketsResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/IncentivizedPackets",
            query_incentivized_packets_request,
            QueryIncentivizedPacketsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def incentivized_packet(
        self,
        query_incentivized_packet_request: "QueryIncentivizedPacketRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryIncentivizedPacketResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/IncentivizedPacket",
            query_incentivized_packet_request,
            QueryIncentivizedPacketResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def incentivized_packets_for_channel(
        self,
        query_incentivized_packets_for_channel_request: "QueryIncentivizedPacketsForChannelRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryIncentivizedPacketsForChannelResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/IncentivizedPacketsForChannel",
            query_incentivized_packets_for_channel_request,
            QueryIncentivizedPacketsForChannelResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def total_recv_fees(
        self,
        query_total_recv_fees_request: "QueryTotalRecvFeesRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryTotalRecvFeesResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/TotalRecvFees",
            query_total_recv_fees_request,
            QueryTotalRecvFeesResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def total_ack_fees(
        self,
        query_total_ack_fees_request: "QueryTotalAckFeesRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryTotalAckFeesResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/TotalAckFees",
            query_total_ack_fees_request,
            QueryTotalAckFeesResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def total_timeout_fees(
        self,
        query_total_timeout_fees_request: "QueryTotalTimeoutFeesRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryTotalTimeoutFeesResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/TotalTimeoutFees",
            query_total_timeout_fees_request,
            QueryTotalTimeoutFeesResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def counterparty_address(
        self,
        query_counterparty_address_request: "QueryCounterpartyAddressRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryCounterpartyAddressResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/CounterpartyAddress",
            query_counterparty_address_request,
            QueryCounterpartyAddressResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def fee_enabled_channels(
        self,
        query_fee_enabled_channels_request: "QueryFeeEnabledChannelsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryFeeEnabledChannelsResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/FeeEnabledChannels",
            query_fee_enabled_channels_request,
            QueryFeeEnabledChannelsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def fee_enabled_channel(
        self,
        query_fee_enabled_channel_request: "QueryFeeEnabledChannelRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryFeeEnabledChannelResponse":
        return await self._unary_unary(
            "/ibc.applications.fee.v1.Query/FeeEnabledChannel",
            query_fee_enabled_channel_request,
            QueryFeeEnabledChannelResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class MsgBase(ServiceBase):
    async def register_counterparty_address(
        self, msg_register_counterparty_address: "MsgRegisterCounterpartyAddress"
    ) -> "MsgRegisterCounterpartyAddressResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def pay_packet_fee(
        self, msg_pay_packet_fee: "MsgPayPacketFee"
    ) -> "MsgPayPacketFeeResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def pay_packet_fee_async(
        self, msg_pay_packet_fee_async: "MsgPayPacketFeeAsync"
    ) -> "MsgPayPacketFeeAsyncResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_register_counterparty_address(
        self,
        stream: "grpclib.server.Stream[MsgRegisterCounterpartyAddress, MsgRegisterCounterpartyAddressResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.register_counterparty_address(request)
        await stream.send_message(response)

    async def __rpc_pay_packet_fee(
        self, stream: "grpclib.server.Stream[MsgPayPacketFee, MsgPayPacketFeeResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.pay_packet_fee(request)
        await stream.send_message(response)

    async def __rpc_pay_packet_fee_async(
        self,
        stream: "grpclib.server.Stream[MsgPayPacketFeeAsync, MsgPayPacketFeeAsyncResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.pay_packet_fee_async(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/ibc.applications.fee.v1.Msg/RegisterCounterpartyAddress": grpclib.const.Handler(
                self.__rpc_register_counterparty_address,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgRegisterCounterpartyAddress,
                MsgRegisterCounterpartyAddressResponse,
            ),
            "/ibc.applications.fee.v1.Msg/PayPacketFee": grpclib.const.Handler(
                self.__rpc_pay_packet_fee,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgPayPacketFee,
                MsgPayPacketFeeResponse,
            ),
            "/ibc.applications.fee.v1.Msg/PayPacketFeeAsync": grpclib.const.Handler(
                self.__rpc_pay_packet_fee_async,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgPayPacketFeeAsync,
                MsgPayPacketFeeAsyncResponse,
            ),
        }


class QueryBase(ServiceBase):
    async def incentivized_packets(
        self, query_incentivized_packets_request: "QueryIncentivizedPacketsRequest"
    ) -> "QueryIncentivizedPacketsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def incentivized_packet(
        self, query_incentivized_packet_request: "QueryIncentivizedPacketRequest"
    ) -> "QueryIncentivizedPacketResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def incentivized_packets_for_channel(
        self,
        query_incentivized_packets_for_channel_request: "QueryIncentivizedPacketsForChannelRequest",
    ) -> "QueryIncentivizedPacketsForChannelResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def total_recv_fees(
        self, query_total_recv_fees_request: "QueryTotalRecvFeesRequest"
    ) -> "QueryTotalRecvFeesResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def total_ack_fees(
        self, query_total_ack_fees_request: "QueryTotalAckFeesRequest"
    ) -> "QueryTotalAckFeesResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def total_timeout_fees(
        self, query_total_timeout_fees_request: "QueryTotalTimeoutFeesRequest"
    ) -> "QueryTotalTimeoutFeesResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def counterparty_address(
        self, query_counterparty_address_request: "QueryCounterpartyAddressRequest"
    ) -> "QueryCounterpartyAddressResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def fee_enabled_channels(
        self, query_fee_enabled_channels_request: "QueryFeeEnabledChannelsRequest"
    ) -> "QueryFeeEnabledChannelsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def fee_enabled_channel(
        self, query_fee_enabled_channel_request: "QueryFeeEnabledChannelRequest"
    ) -> "QueryFeeEnabledChannelResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_incentivized_packets(
        self,
        stream: "grpclib.server.Stream[QueryIncentivizedPacketsRequest, QueryIncentivizedPacketsResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.incentivized_packets(request)
        await stream.send_message(response)

    async def __rpc_incentivized_packet(
        self,
        stream: "grpclib.server.Stream[QueryIncentivizedPacketRequest, QueryIncentivizedPacketResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.incentivized_packet(request)
        await stream.send_message(response)

    async def __rpc_incentivized_packets_for_channel(
        self,
        stream: "grpclib.server.Stream[QueryIncentivizedPacketsForChannelRequest, QueryIncentivizedPacketsForChannelResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.incentivized_packets_for_channel(request)
        await stream.send_message(response)

    async def __rpc_total_recv_fees(
        self,
        stream: "grpclib.server.Stream[QueryTotalRecvFeesRequest, QueryTotalRecvFeesResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.total_recv_fees(request)
        await stream.send_message(response)

    async def __rpc_total_ack_fees(
        self,
        stream: "grpclib.server.Stream[QueryTotalAckFeesRequest, QueryTotalAckFeesResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.total_ack_fees(request)
        await stream.send_message(response)

    async def __rpc_total_timeout_fees(
        self,
        stream: "grpclib.server.Stream[QueryTotalTimeoutFeesRequest, QueryTotalTimeoutFeesResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.total_timeout_fees(request)
        await stream.send_message(response)

    async def __rpc_counterparty_address(
        self,
        stream: "grpclib.server.Stream[QueryCounterpartyAddressRequest, QueryCounterpartyAddressResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.counterparty_address(request)
        await stream.send_message(response)

    async def __rpc_fee_enabled_channels(
        self,
        stream: "grpclib.server.Stream[QueryFeeEnabledChannelsRequest, QueryFeeEnabledChannelsResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.fee_enabled_channels(request)
        await stream.send_message(response)

    async def __rpc_fee_enabled_channel(
        self,
        stream: "grpclib.server.Stream[QueryFeeEnabledChannelRequest, QueryFeeEnabledChannelResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.fee_enabled_channel(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/ibc.applications.fee.v1.Query/IncentivizedPackets": grpclib.const.Handler(
                self.__rpc_incentivized_packets,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryIncentivizedPacketsRequest,
                QueryIncentivizedPacketsResponse,
            ),
            "/ibc.applications.fee.v1.Query/IncentivizedPacket": grpclib.const.Handler(
                self.__rpc_incentivized_packet,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryIncentivizedPacketRequest,
                QueryIncentivizedPacketResponse,
            ),
            "/ibc.applications.fee.v1.Query/IncentivizedPacketsForChannel": grpclib.const.Handler(
                self.__rpc_incentivized_packets_for_channel,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryIncentivizedPacketsForChannelRequest,
                QueryIncentivizedPacketsForChannelResponse,
            ),
            "/ibc.applications.fee.v1.Query/TotalRecvFees": grpclib.const.Handler(
                self.__rpc_total_recv_fees,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryTotalRecvFeesRequest,
                QueryTotalRecvFeesResponse,
            ),
            "/ibc.applications.fee.v1.Query/TotalAckFees": grpclib.const.Handler(
                self.__rpc_total_ack_fees,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryTotalAckFeesRequest,
                QueryTotalAckFeesResponse,
            ),
            "/ibc.applications.fee.v1.Query/TotalTimeoutFees": grpclib.const.Handler(
                self.__rpc_total_timeout_fees,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryTotalTimeoutFeesRequest,
                QueryTotalTimeoutFeesResponse,
            ),
            "/ibc.applications.fee.v1.Query/CounterpartyAddress": grpclib.const.Handler(
                self.__rpc_counterparty_address,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryCounterpartyAddressRequest,
                QueryCounterpartyAddressResponse,
            ),
            "/ibc.applications.fee.v1.Query/FeeEnabledChannels": grpclib.const.Handler(
                self.__rpc_fee_enabled_channels,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryFeeEnabledChannelsRequest,
                QueryFeeEnabledChannelsResponse,
            ),
            "/ibc.applications.fee.v1.Query/FeeEnabledChannel": grpclib.const.Handler(
                self.__rpc_fee_enabled_channel,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryFeeEnabledChannelRequest,
                QueryFeeEnabledChannelResponse,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ibc/core/commitment/v1/commitment.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass
from typing import List

import betterproto

from ..... import ics23 as ____ics23__


@dataclass(eq=False, repr=False)
class MerkleRoot(betterproto.Message):
    """
    MerkleRoot defines a merkle root hash.
     In the Cosmos SDK, the AppHash of a block header becomes the root.
    """

    hash: bytes = betterproto.bytes_field(1)


@dataclass(eq=False, repr=False)
class MerklePrefix(betterproto.Message):
    """
    MerklePrefix is merkle path prefixed to the key.
     The constructed key from the Path and the key will be append(Path.KeyPath,
     append(Path.KeyPrefix, key...))
    """

    key_prefix: bytes = betterproto.bytes_field(1)


@dataclass(eq=False, repr=False)
class MerklePath(betterproto.Message):
    """
    MerklePath is the path used to verify commitment proofs, which can be an
     arbitrary structured object (defined by a commitment type).
     MerklePath is represented from root-to-leaf
    """

    key_path: List[str] = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class MerkleProof(betterproto.Message):
    """
    MerkleProof is a wrapper type over a chain of CommitmentProofs.
     It demonstrates membership or non-membership for an element or set of
     elements, verifiable in conjunction with a known commitment root. Proofs
     should be succinct.
     MerkleProofs are ordered from leaf-to-root
    """

    proofs: List["____ics23__.CommitmentProof"] = betterproto.message_field(1)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: ibc/applications/transfer/v1/genesis.proto, ibc/applications/transfer/v1/query.proto, ibc/applications/transfer/v1/transfer.proto, ibc/applications/transfer/v1/tx.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    List,
    Optional,
)

import betterproto
import grpclib
from betterproto.grpc.grpclib_server import ServiceBase

from .....cosmos.base import v1beta1 as ____cosmos_base_v1_beta1__
from .....cosmos.base.query import v1beta1 as ____cosmos_base_query_v1_beta1__
from ....core.client import v1 as ___core_client_v1__


if TYPE_CHECKING:
    import grpclib.server
    from betterproto.grpc.grpclib_client import MetadataLike
    from grpclib.metadata import Deadline


@dataclass(eq=False, repr=False)
class MsgTransfer(betterproto.Message):
    """
    MsgTransfer defines a msg to transfer fungible tokens (i.e Coins) between
     ICS20 enabled chains. See ICS Spec here:
     https://github.com/cosmos/ibc/tree/master/spec/app/ics-020-fungible-token-transfer#data-structures
    """

    source_port: str = betterproto.string_field(1)
    """the port on which the packet will be sent"""

    source_channel: str = betterproto.string_field(2)
    """the channel by which the packet will be sent"""

    token: "____cosmos_base_v1_beta1__.Coin" = betterproto.message_field(3)
    """the tokens to be transferred"""

    sender: str = betterproto.string_field(4)
    """the sender address"""

    receiver: str = betterproto.string_field(5)
    """the recipient address on the destination chain"""

    timeout_height: "___core_client_v1__.Height" = betterproto.message_field(6)
    """
    Timeout height relative to the current block height.
     The timeout is disabled when set to 0.
    """

    timeout_timestamp: int = betterproto.uint64_field(7)
    """
    Timeout timestamp in absolute nanoseconds since unix epoch.
     The timeout is disabled when set to 0.
    """


@dataclass(eq=False, repr=False)
class MsgTransferResponse(betterproto.Message):
    """MsgTransferResponse defines the Msg/Transfer response type."""

    pass


@dataclass(eq=False, repr=False)
class DenomTrace(betterproto.Message):
    """
    DenomTrace contains the base denomination for ICS20 fungible tokens and the
     source tracing information path.
    """

    path: str = betterproto.string_field(1)
    """
    path defines the chain of port/channel identifiers used for tracing the
     source of the fungible token.
    """

    base_denom: str = betterproto.string_field(2)
    """base denomination of the relayed fungible token."""


@dataclass(eq=False, repr=False)
class Params(betterproto.Message):
    """
    Params defines the set of IBC transfer parameters.
     NOTE: To prevent a single token from being transferred, set the
     TransfersEnabled parameter to true and then set the bank module's SendEnabled
     parameter for the denomination to false.
    """

    send_enabled: bool = betterproto.bool_field(1)
    """
    send_enabled enables or disables all cross-chain token transfers from this
     chain.
    """

    receive_enabled: bool = betterproto.bool_field(2)
    """
    receive_enabled enables or disables all cross-chain token transfers to this
     chain.
    """


@dataclass(eq=False, repr=False)
class QueryDenomTraceRequest(betterproto.Message):
    """
    QueryDenomTraceRequest is the request type for the Query/DenomTrace RPC
     method
    """

    hash: str = betterproto.string_field(1)
    """hash (in hex format) of the denomination trace information."""


@dataclass(eq=False, repr=False)
class QueryDenomTraceResponse(betterproto.Message):
    """
    QueryDenomTraceResponse is the response type for the Query/DenomTrace RPC
     method.
    """

    denom_trace: "DenomTrace" = betterproto.message_field(1)
    """denom_trace returns the requested denomination trace information."""


@dataclass(eq=False, repr=False)
class QueryDenomTracesRequest(betterproto.Message):
    """
    QueryConnectionsRequest is the request type for the Query/DenomTraces RPC
     method
    """

    pagination: "____cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )
    """pagination defines an optional pagination for the request."""


@dataclass(eq=False, repr=False)
class QueryDenomTracesResponse(betterproto.Message):
    """
    QueryConnectionsResponse is the response type for the Query/DenomTraces RPC
     method.
    """

    denom_traces: List["DenomTrace"] = betterproto.message_field(1)
    """denom_traces returns all denominations trace information."""

    pagination: "____cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )
    """pagination defines the pagination in the response."""


@dataclass(eq=False, repr=False)
class QueryParamsRequest(betterproto.Message):
    """
    QueryParamsRequest is the request type for the Query/Params RPC method.
    """

    pass


@dataclass(eq=False, repr=False)
class QueryParamsResponse(betterproto.Message):
    """
    QueryParamsResponse is the response type for the Query/Params RPC method.
    """

    params: "Params" = betterproto.message_field(1)
    """params defines the parameters of the module."""


@dataclass(eq=False, repr=False)
class QueryDenomHashRequest(betterproto.Message):
    """
    QueryDenomHashRequest is the request type for the Query/DenomHash RPC
     method
    """

    trace: str = betterproto.string_field(1)
    """The denomination trace ([port_id]/[channel_id])+/[denom]"""


@dataclass(eq=False, repr=False)
class QueryDenomHashResponse(betterproto.Message):
    """
    QueryDenomHashResponse is the response type for the Query/DenomHash RPC
     method.
    """

    hash: str = betterproto.string_field(1)
    """hash (in hex format) of the denomination trace information."""


@dataclass(eq=False, repr=False)
class GenesisState(betterproto.Message):
    """GenesisState defines the ibc-transfer genesis state"""

    port_id: str = betterproto.string_field(1)
    denom_traces: List["DenomTrace"] = betterproto.message_field(2)
    params: "Params" = betterproto.message_field(3)


class MsgStub(betterproto.ServiceStub):
    async def transfer(
        self,
        msg_transfer: "MsgTransfer",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "MsgTransferResponse":
        return await self._unary_unary(
            "/ibc.applications.transfer.v1.Msg/Transfer",
            msg_transfer,
            MsgTransferResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class QueryStub(betterproto.ServiceStub):
    async def denom_trace(
        self,
        query_denom_trace_request: "QueryDenomTraceRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryDenomTraceResponse":
        return await self._unary_unary(
            "/ibc.applications.transfer.v1.Query/DenomTrace",
            query_denom_trace_request,
            QueryDenomTraceResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def denom_traces(
        self,
        query_denom_traces_request: "QueryDenomTracesRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryDenomTracesResponse":
        return await self._unary_unary(
            "/ibc.applications.transfer.v1.Query/DenomTraces",
            query_denom_traces_request,
            QueryDenomTracesResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def params(
        self,
        query_params_request: "QueryParamsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryParamsResponse":
        return await self._unary_unary(
            "/ibc.applications.transfer.v1.Query/Params",
            query_params_request,
            QueryParamsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def denom_hash(
        self,
        query_denom_hash_request: "QueryDenomHashRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryDenomHashResponse":
        return await self._unary_unary(
            "/ibc.applications.transfer.v1.Query/DenomHash",
            query_denom_hash_request,
            QueryDenomHashResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class MsgBase(ServiceBase):
    async def transfer(self, msg_transfer: "MsgTransfer") -> "MsgTransferResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_transfer(
        self, stream: "grpclib.server.Stream[MsgTransfer, MsgTransferResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.transfer(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/ibc.applications.transfer.v1.Msg/Transfer": grpclib.const.Handler(
                self.__rpc_transfer,
                grpclib.const.Cardinality.UNARY_UNARY,
                MsgTransfer,
                MsgTransferResponse,
            ),
        }


class QueryBase(ServiceBase):
    async def denom_trace(
        self, query_denom_trace_request: "QueryDenomTraceRequest"
    ) -> "QueryDenomTraceResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def denom_traces(
        self, query_denom_traces_request: "QueryDenomTracesRequest"
    ) -> "QueryDenomTracesResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def params(
        self, query_params_request: "QueryParamsRequest"
    ) -> "QueryParamsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def denom_hash(
        self, query_denom_hash_request: "QueryDenomHashRequest"
    ) -> "QueryDenomHashResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_denom_trace(
        self,
        stream: "grpclib.server.Stream[QueryDenomTraceRequest, QueryDenomTraceResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.denom_trace(request)
        await stream.send_message(response)

    async def __rpc_denom_traces(
        self,
        stream: "grpclib.server.Stream[QueryDenomTracesRequest, QueryDenomTracesResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.denom_traces(request)
        await stream.send_message(response)

    async def __rpc_params(
        self, stream: "grpclib.server.Stream[QueryParamsRequest, QueryParamsResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.params(request)
        await stream.send_message(response)

    async def __rpc_denom_hash(
        self,
        stream: "grpclib.server.Stream[QueryDenomHashRequest, QueryDenomHashResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.denom_hash(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/ibc.applications.transfer.v1.Query/DenomTrace": grpclib.const.Handler(
                self.__rpc_denom_trace,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryDenomTraceRequest,
                QueryDenomTraceResponse,
            ),
            "/ibc.applications.transfer.v1.Query/DenomTraces": grpclib.const.Handler(
                self.__rpc_denom_traces,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryDenomTracesRequest,
                QueryDenomTracesResponse,
            ),
            "/ibc.applications.transfer.v1.Query/Params": grpclib.const.Handler(
                self.__rpc_params,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryParamsRequest,
                QueryParamsResponse,
            ),
            "/ibc.applications.transfer.v1.Query/DenomHash": grpclib.const.Handler(
                self.__rpc_denom_hash,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryDenomHashRequest,
                QueryDenomHashResponse,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: cosmos_proto/cosmos.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass

import betterproto



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: glitterchain/index/dataset.proto, glitterchain/index/genesis.proto, glitterchain/index/index.proto, glitterchain/index/params.proto, glitterchain/index/query.proto, glitterchain/index/tx.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass
from datetime import datetime
from typing import (
    TYPE_CHECKING,
    Dict,
    List,
    Optional,
)

import betterproto
import grpclib
from betterproto.grpc.grpclib_server import ServiceBase

from ...cosmos.base.query import v1beta1 as __cosmos_base_query_v1_beta1__


if TYPE_CHECKING:
    import grpclib.server
    from betterproto.grpc.grpclib_client import MetadataLike
    from grpclib.metadata import Deadline


class ServiceStatus(betterproto.Enum):
    Service_Status_Unset = 0
    Service_Status_Start = 1
    Service_Status_Stop = 2
    Service_Status_Delete = 3


@dataclass(eq=False, repr=False)
class Table(betterproto.Message):
    table_name: str = betterproto.string_field(1)
    description: str = betterproto.string_field(2)
    update_time: datetime = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class Cpdt(betterproto.Message):
    """consumer pledge dataset token"""

    dataset_name: str = betterproto.string_field(1)
    consumer_address: str = betterproto.string_field(2)
    amount: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class Dataset(betterproto.Message):
    dataset_name: str = betterproto.string_field(1)
    work_status: "ServiceStatus" = betterproto.enum_field(2)
    owner_address: str = betterproto.string_field(3)
    expiration_time: datetime = betterproto.message_field(4)
    hosts: str = betterproto.string_field(5)
    manage_addresses: str = betterproto.string_field(6)
    tables: List["Table"] = betterproto.message_field(7)
    sum_cpdt: str = betterproto.string_field(8)
    description: str = betterproto.string_field(9)
    update_time: datetime = betterproto.message_field(10)


@dataclass(eq=False, repr=False)
class DatasetExpiration(betterproto.Message):
    dataset_names: List[str] = betterproto.string_field(1)
    expiration_time: datetime = betterproto.message_field(11)


@dataclass(eq=False, repr=False)
class ColumnMeta(betterproto.Message):
    """ColumnDesc"""

    name: str = betterproto.string_field(1)
    type: str = betterproto.string_field(2)
    comment: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class TableDesc(betterproto.Message):
    """TableDesc"""

    table_name: str = betterproto.string_field(1)
    engine: str = betterproto.string_field(2)
    comment: str = betterproto.string_field(3)
    columns: List["ColumnMeta"] = betterproto.message_field(4)


@dataclass(eq=False, repr=False)
class Website(betterproto.Message):
    """Website"""

    github: str = betterproto.string_field(1)
    discord: str = betterproto.string_field(2)
    telegram: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class App(betterproto.Message):
    """App"""

    img: str = betterproto.string_field(1)
    name: str = betterproto.string_field(2)
    website: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class DatasetDesc(betterproto.Message):
    """DatasetDesc"""

    description: str = betterproto.string_field(1)
    cover_img: str = betterproto.string_field(2)
    cid: str = betterproto.string_field(3)
    website: "Website" = betterproto.message_field(4)
    app: List["App"] = betterproto.message_field(5)
    storage: str = betterproto.string_field(6)
    row_cnt: int = betterproto.int64_field(7)


@dataclass(eq=False, repr=False)
class EditTableRequest(betterproto.Message):
    from_address: str = betterproto.string_field(1)
    dataset_name: str = betterproto.string_field(2)
    table_name: str = betterproto.string_field(3)
    description: str = betterproto.string_field(5)


@dataclass(eq=False, repr=False)
class EditTableResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class CreateDatasetRequest(betterproto.Message):
    from_address: str = betterproto.string_field(1)
    dataset_name: str = betterproto.string_field(2)
    work_status: "ServiceStatus" = betterproto.enum_field(3)
    hosts: str = betterproto.string_field(4)
    manage_addresses: str = betterproto.string_field(5)
    description: str = betterproto.string_field(7)
    duration: int = betterproto.int64_field(8)


@dataclass(eq=False, repr=False)
class CreateDatasetResponse(betterproto.Message):
    expiration_time: datetime = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class EditDatasetRequest(betterproto.Message):
    from_address: str = betterproto.string_field(1)
    dataset_name: str = betterproto.string_field(2)
    work_status: "ServiceStatus" = betterproto.enum_field(3)
    hosts: str = betterproto.string_field(4)
    manage_addresses: str = betterproto.string_field(5)
    description: str = betterproto.string_field(7)


@dataclass(eq=False, repr=False)
class EditDatasetResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class RenewalDatasetRequest(betterproto.Message):
    from_address: str = betterproto.string_field(1)
    dataset_name: str = betterproto.string_field(2)
    duration: int = betterproto.int64_field(3)


@dataclass(eq=False, repr=False)
class RenewalDatasetResponse(betterproto.Message):
    expiration_time: datetime = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class Params(betterproto.Message):
    """Params defines the parameters for the module."""

    fee_per_dataset_per_second: str = betterproto.string_field(1)
    grace_period: int = betterproto.int64_field(2)


@dataclass(eq=False, repr=False)
class QueryParamsRequest(betterproto.Message):
    """QueryParamsRequest is request type for the Query/Params RPC method."""

    pass


@dataclass(eq=False, repr=False)
class QueryParamsResponse(betterproto.Message):
    """
    QueryParamsResponse is response type for the Query/Params RPC method.
    """

    params: "Params" = betterproto.message_field(1)
    """params holds all the parameters of this module."""


@dataclass(eq=False, repr=False)
class QueryDatesetRequest(betterproto.Message):
    dataset_name: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class QueryDatesetResponse(betterproto.Message):
    dateset: "Dataset" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class QueryDatasetExpirationsRequest(betterproto.Message):
    pagination: "__cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )


@dataclass(eq=False, repr=False)
class QueryDatasetExpirationsResponse(betterproto.Message):
    datasets: List["DatasetExpiration"] = betterproto.message_field(1)
    pagination: "__cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )


@dataclass(eq=False, repr=False)
class QueryDatesetsRequest(betterproto.Message):
    pagination: "__cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )


@dataclass(eq=False, repr=False)
class QueryDatesetsResponse(betterproto.Message):
    datasets: List["Dataset"] = betterproto.message_field(1)
    pagination: "__cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )


@dataclass(eq=False, repr=False)
class QueryCpdtRequest(betterproto.Message):
    dataset_name: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class QueryCpdtResponse(betterproto.Message):
    cpd_ts: List["Cpdt"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class QueryCpdTsRequest(betterproto.Message):
    pagination: "__cosmos_base_query_v1_beta1__.PageRequest" = (
        betterproto.message_field(1)
    )


@dataclass(eq=False, repr=False)
class QueryCpdTsResponse(betterproto.Message):
    cpd_ts: List["Cpdt"] = betterproto.message_field(1)
    pagination: "__cosmos_base_query_v1_beta1__.PageResponse" = (
        betterproto.message_field(2)
    )


@dataclass(eq=False, repr=False)
class GenesisState(betterproto.Message):
    """GenesisState defines the index module's genesis state."""

    params: "Params" = betterproto.message_field(1)
    datasets: List["Dataset"] = betterproto.message_field(2)
    cpd_ts: List["Cpdt"] = betterproto.message_field(3)


class MsgStub(betterproto.ServiceStub):
    async def create_dataset(
        self,
        create_dataset_request: "CreateDatasetRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "CreateDatasetResponse":
        return await self._unary_unary(
            "/glitterchain.index.Msg/CreateDataset",
            create_dataset_request,
            CreateDatasetResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def edit_dataset(
        self,
        edit_dataset_request: "EditDatasetRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "EditDatasetResponse":
        return await self._unary_unary(
            "/glitterchain.index.Msg/EditDataset",
            edit_dataset_request,
            EditDatasetResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def renewal_dataset(
        self,
        renewal_dataset_request: "RenewalDatasetRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "RenewalDatasetResponse":
        return await self._unary_unary(
            "/glitterchain.index.Msg/RenewalDataset",
            renewal_dataset_request,
            RenewalDatasetResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def edit_table(
        self,
        edit_table_request: "EditTableRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "EditTableResponse":
        return await self._unary_unary(
            "/glitterchain.index.Msg/EditTable",
            edit_table_request,
            EditTableResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class QueryStub(betterproto.ServiceStub):
    async def params(
        self,
        query_params_request: "QueryParamsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryParamsResponse":
        return await self._unary_unary(
            "/glitterchain.index.Query/Params",
            query_params_request,
            QueryParamsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def query_dateset(
        self,
        query_dateset_request: "QueryDatesetRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryDatesetResponse":
        return await self._unary_unary(
            "/glitterchain.index.Query/QueryDateset",
            query_dateset_request,
            QueryDatesetResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def query_datesets(
        self,
        query_datesets_request: "QueryDatesetsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryDatesetsResponse":
        return await self._unary_unary(
            "/glitterchain.index.Query/QueryDatesets",
            query_datesets_request,
            QueryDatesetsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def query_dataset_expirations(
        self,
        query_dataset_expirations_request: "QueryDatasetExpirationsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryDatasetExpirationsResponse":
        return await self._unary_unary(
            "/glitterchain.index.Query/QueryDatasetExpirations",
            query_dataset_expirations_request,
            QueryDatasetExpirationsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def query_cpdt(
        self,
        query_cpdt_request: "QueryCpdtRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryCpdtResponse":
        return await self._unary_unary(
            "/glitterchain.index.Query/QueryCPDT",
            query_cpdt_request,
            QueryCpdtResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def query_cpd_ts(
        self,
        query_cpd_ts_request: "QueryCpdTsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> "QueryCpdTsResponse":
        return await self._unary_unary(
            "/glitterchain.index.Query/QueryCPDTs",
            query_cpd_ts_request,
            QueryCpdTsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class MsgBase(ServiceBase):
    async def create_dataset(
        self, create_dataset_request: "CreateDatasetRequest"
    ) -> "CreateDatasetResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def edit_dataset(
        self, edit_dataset_request: "EditDatasetRequest"
    ) -> "EditDatasetResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def renewal_dataset(
        self, renewal_dataset_request: "RenewalDatasetRequest"
    ) -> "RenewalDatasetResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def edit_table(
        self, edit_table_request: "EditTableRequest"
    ) -> "EditTableResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_create_dataset(
        self,
        stream: "grpclib.server.Stream[CreateDatasetRequest, CreateDatasetResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.create_dataset(request)
        await stream.send_message(response)

    async def __rpc_edit_dataset(
        self, stream: "grpclib.server.Stream[EditDatasetRequest, EditDatasetResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.edit_dataset(request)
        await stream.send_message(response)

    async def __rpc_renewal_dataset(
        self,
        stream: "grpclib.server.Stream[RenewalDatasetRequest, RenewalDatasetResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.renewal_dataset(request)
        await stream.send_message(response)

    async def __rpc_edit_table(
        self, stream: "grpclib.server.Stream[EditTableRequest, EditTableResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.edit_table(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/glitterchain.index.Msg/CreateDataset": grpclib.const.Handler(
                self.__rpc_create_dataset,
                grpclib.const.Cardinality.UNARY_UNARY,
                CreateDatasetRequest,
                CreateDatasetResponse,
            ),
            "/glitterchain.index.Msg/EditDataset": grpclib.const.Handler(
                self.__rpc_edit_dataset,
                grpclib.const.Cardinality.UNARY_UNARY,
                EditDatasetRequest,
                EditDatasetResponse,
            ),
            "/glitterchain.index.Msg/RenewalDataset": grpclib.const.Handler(
                self.__rpc_renewal_dataset,
                grpclib.const.Cardinality.UNARY_UNARY,
                RenewalDatasetRequest,
                RenewalDatasetResponse,
            ),
            "/glitterchain.index.Msg/EditTable": grpclib.const.Handler(
                self.__rpc_edit_table,
                grpclib.const.Cardinality.UNARY_UNARY,
                EditTableRequest,
                EditTableResponse,
            ),
        }


class QueryBase(ServiceBase):
    async def params(
        self, query_params_request: "QueryParamsRequest"
    ) -> "QueryParamsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def query_dateset(
        self, query_dateset_request: "QueryDatesetRequest"
    ) -> "QueryDatesetResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def query_datesets(
        self, query_datesets_request: "QueryDatesetsRequest"
    ) -> "QueryDatesetsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def query_dataset_expirations(
        self, query_dataset_expirations_request: "QueryDatasetExpirationsRequest"
    ) -> "QueryDatasetExpirationsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def query_cpdt(
        self, query_cpdt_request: "QueryCpdtRequest"
    ) -> "QueryCpdtResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def query_cpd_ts(
        self, query_cpd_ts_request: "QueryCpdTsRequest"
    ) -> "QueryCpdTsResponse":
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_params(
        self, stream: "grpclib.server.Stream[QueryParamsRequest, QueryParamsResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.params(request)
        await stream.send_message(response)

    async def __rpc_query_dateset(
        self, stream: "grpclib.server.Stream[QueryDatesetRequest, QueryDatesetResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.query_dateset(request)
        await stream.send_message(response)

    async def __rpc_query_datesets(
        self,
        stream: "grpclib.server.Stream[QueryDatesetsRequest, QueryDatesetsResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.query_datesets(request)
        await stream.send_message(response)

    async def __rpc_query_dataset_expirations(
        self,
        stream: "grpclib.server.Stream[QueryDatasetExpirationsRequest, QueryDatasetExpirationsResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.query_dataset_expirations(request)
        await stream.send_message(response)

    async def __rpc_query_cpdt(
        self, stream: "grpclib.server.Stream[QueryCpdtRequest, QueryCpdtResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.query_cpdt(request)
        await stream.send_message(response)

    async def __rpc_query_cpd_ts(
        self, stream: "grpclib.server.Stream[QueryCpdTsRequest, QueryCpdTsResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.query_cpd_ts(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/glitterchain.index.Query/Params": grpclib.const.Handler(
                self.__rpc_params,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryParamsRequest,
                QueryParamsResponse,
            ),
            "/glitterchain.index.Query/QueryDateset": grpclib.const.Handler(
                self.__rpc_query_dateset,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryDatesetRequest,
                QueryDatesetResponse,
            ),
            "/glitterchain.index.Query/QueryDatesets": grpclib.const.Handler(
                self.__rpc_query_datesets,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryDatesetsRequest,
                QueryDatesetsResponse,
            ),
            "/glitterchain.index.Query/QueryDatasetExpirations": grpclib.const.Handler(
                self.__rpc_query_dataset_expirations,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryDatasetExpirationsRequest,
                QueryDatasetExpirationsResponse,
            ),
            "/glitterchain.index.Query/QueryCPDT": grpclib.const.Handler(
                self.__rpc_query_cpdt,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryCpdtRequest,
                QueryCpdtResponse,
            ),
            "/glitterchain.index.Query/QueryCPDTs": grpclib.const.Handler(
                self.__rpc_query_cpd_ts,
                grpclib.const.Cardinality.UNARY_UNARY,
                QueryCpdTsRequest,
                QueryCpdTsResponse,
            ),
        }
